pub struct FileCacheBootstrapStore;Trait Implementations
Sourceimpl BootstrapStore for FileCacheBootstrapStore
impl BootstrapStore for FileCacheBootstrapStore
Sourcefn has_bootstrap_registry(
&self,
reg_type: &IanaRegistryType,
) -> Result<bool, RdapClientError>
fn has_bootstrap_registry( &self, reg_type: &IanaRegistryType, ) -> Result<bool, RdapClientError>
Called when store is checked to see if it has a valid bootstrap registry. Read more
Sourcefn put_bootstrap_registry(
&self,
reg_type: &IanaRegistryType,
registry: IanaRegistry,
http_data: HttpData,
) -> Result<(), RdapClientError>
fn put_bootstrap_registry( &self, reg_type: &IanaRegistryType, registry: IanaRegistry, http_data: HttpData, ) -> Result<(), RdapClientError>
Puts a registry into the bootstrap registry store.
Sourcefn get_dns_urls(
&self,
ldh: &str,
) -> Result<Option<Vec<String>>, RdapClientError>
fn get_dns_urls( &self, ldh: &str, ) -> Result<Option<Vec<String>>, RdapClientError>
Get the URLs associated with the IANA RDAP DNS bootstrap. Read more
Sourcefn get_asn_urls(
&self,
asn: &str,
) -> Result<Option<Vec<String>>, RdapClientError>
fn get_asn_urls( &self, asn: &str, ) -> Result<Option<Vec<String>>, RdapClientError>
Get the URLs associated with the IANA RDAP ASN bootstrap. Read more
Sourcefn get_ipv4_urls(
&self,
ipv4: &str,
) -> Result<Option<Vec<String>>, RdapClientError>
fn get_ipv4_urls( &self, ipv4: &str, ) -> Result<Option<Vec<String>>, RdapClientError>
Get the URLs associated with the IANA RDAP IPv4 bootstrap. Read more
Sourcefn get_ipv6_urls(
&self,
ipv6: &str,
) -> Result<Option<Vec<String>>, RdapClientError>
fn get_ipv6_urls( &self, ipv6: &str, ) -> Result<Option<Vec<String>>, RdapClientError>
Get the URLs associated with the IANA RDAP IPv6 bootstrap. Read more
Sourcefn get_tag_urls(
&self,
tag: &str,
) -> Result<Option<Vec<String>>, RdapClientError>
fn get_tag_urls( &self, tag: &str, ) -> Result<Option<Vec<String>>, RdapClientError>
Get the URLs associated with the IANA RDAP Object Tags bootstrap. Read more
Sourcefn get_domain_query_urls(
&self,
query_type: &QueryType,
) -> Result<Option<Vec<String>>, RdapClientError>
fn get_domain_query_urls( &self, query_type: &QueryType, ) -> Result<Option<Vec<String>>, RdapClientError>
Get the urls for a domain or nameserver (which are domain names) query type. Read more
Sourcefn get_autnum_query_urls(
&self,
query_type: &QueryType,
) -> Result<Option<Vec<String>>, RdapClientError>
fn get_autnum_query_urls( &self, query_type: &QueryType, ) -> Result<Option<Vec<String>>, RdapClientError>
Get the urls for an autnum query type. Read more
Sourcefn get_ipv4_query_urls(
&self,
query_type: &QueryType,
) -> Result<Option<Vec<String>>, RdapClientError>
fn get_ipv4_query_urls( &self, query_type: &QueryType, ) -> Result<Option<Vec<String>>, RdapClientError>
Get the urls for an IPv4 query type. Read more
Sourcefn get_ipv6_query_urls(
&self,
query_type: &QueryType,
) -> Result<Option<Vec<String>>, RdapClientError>
fn get_ipv6_query_urls( &self, query_type: &QueryType, ) -> Result<Option<Vec<String>>, RdapClientError>
Get the urls for an IPv6 query type. Read more
Sourcefn get_entity_handle_query_urls(
&self,
query_type: &QueryType,
) -> Result<Option<Vec<String>>, RdapClientError>
fn get_entity_handle_query_urls( &self, query_type: &QueryType, ) -> Result<Option<Vec<String>>, RdapClientError>
Get the urls for an entity handle query type. Read more
Sourcefn get_tag_query_urls(
&self,
tag: &str,
) -> Result<Option<Vec<String>>, RdapClientError>
fn get_tag_query_urls( &self, tag: &str, ) -> Result<Option<Vec<String>>, RdapClientError>
Get the urls for an object tag query type. Read more